==> create-tailwindcss-boilerplate-1.5.2.tgz: package/README.md <==
# Create Tailwind CSS Boilerplate

A bare-bones Tailwind CSS boilerplate.

It creates a simple HTML + CSS template with [Tailwind CSS](https://tailwindcss.com)
support, served by [Parcel](https://parceljs.org) and using [PurgeCSS](https://purgecss.com)
in production builds.

## Getting started

### Requirements

[Yarn](https://yarnpkg.com) is suggested, but not required. The project will be
set up with [npm](https://www.npmjs.com/get-npm) if Yarn is not found.

### Create boilerplate

```bash
$ yarn create tailwindcss-boilerplate

# or

$ npx create-tailwindcss-boilerplate
```

Follow instructions at the prompt to create your project:

```bash
? Choose project root directory my-project
  ✔ Create directory structure
  ✔ Create project files
  ✔ Create templates
  ✔ Set up dependencies
```

### Run server

```bash
$ yarn dev
```

Open your favorite text editor and start coding!

## Build for production

```bash
$ yarn build
```

Build files will end up in `/dist`.

## Contributing

If you want to add a feature, fix a bug or propose a change, please feel free to
[submit an issue](https://github.com/michelegera/create-tailwindcss-boilerplate/issues/new) or [open a pull request](https://github.com/michelegera/create-tailwindcss-boilerplate/compare).

Thanks to [all the contributors](https://github.com/michelegera/create-tailwindcss-boilerplate/graphs/contributors)!

## Acknowledgments

This project piggybacks on the excellent [TailwindCSS + Parcel + PurgeCSS
Starter Project](https://github.com/didiercatz/tailwindcss-parcel-boilerplate)
by [didiercatz](https://github.com/didiercatz). Check out his [blog
post](https://dev.to/didiercatz/getting-started-with-tailwindcss-in-seconds-8p2)
on getting started with Tailwind CSS.

==> create-tailwindcss-boilerplate-1.5.4.tgz: package/README.md <==
# Create Tailwind CSS Boilerplate

A bare-bones Tailwind CSS boilerplate.

It creates a simple HTML + CSS template with [Tailwind CSS](https://tailwindcss.com)
support, served by [Parcel](https://parceljs.org) and using [PurgeCSS](https://purgecss.com)
in production builds.

## Getting started

### Requirements

[Yarn](https://yarnpkg.com) is suggested, but not required. The project will be
set up with [npm](https://www.npmjs.com/get-npm) if Yarn is not found.

### Create boilerplate

```bash
$ yarn create tailwindcss-boilerplate

# or

$ npx create-tailwindcss-boilerplate
```

Follow instructions at the prompt to create your project:

```bash
? Name your project root directory my-project
  ✔ Create directory structure
  ✔ Create project files
  ✔ Create templates
  ✔ Set up dependencies
```

### Run server

```bash
$ yarn dev
```

Open your favorite text editor and start coding!

## Build for production

```bash
$ yarn build
```

Build files will end up in `/dist`.

## Contributing

If you want to add a feature, fix a bug or propose a change, please feel free to
[submit an issue](https://github.com/michelegera/create-tailwindcss-boilerplate/issues/new) or [open a pull request](https://github.com/michelegera/create-tailwindcss-boilerplate/compare).

Thanks to [all the contributors](https://github.com/michelegera/create-tailwindcss-boilerplate/graphs/contributors)!

## Acknowledgments

This project piggybacks on the excellent [TailwindCSS + Parcel + PurgeCSS
Starter Project](https://github.com/didiercatz/tailwindcss-parcel-boilerplate)
by [didiercatz](https://github.com/didiercatz). Check out his [blog
post](https://dev.to/didiercatz/getting-started-with-tailwindcss-in-seconds-8p2)
on getting started with Tailwind CSS.
